/*
 * Building this file in a library ensures translations are automatically loaded
 * when an application makes use of the library.
 *
 *
 * Copyright 2014 Aurélien Gâteau <agateau@kde.org>
 * Copyright 2015 Alex Merry <alex.merry@kde.org>
 * Copyright 2017 Alexander Volkov <support@rusbitech.ru>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include <QCoreApplication>
#include <QLocale>
#include <QThread>
#include <QTimer>
#include <QTranslator>

namespace {

    void load()
    {
        QString fullPath(QLatin1String("/usr/share/libqsane/i18n"));
        if (fullPath.isEmpty()) {
            return;
        }
        QTranslator *translator = new QTranslator(QCoreApplication::instance());
        if (!translator->load(QLocale::system(), QLatin1String("libqsane"), QLatin1String("_"), fullPath)) {
            delete translator;
            return;
        }
        QCoreApplication::instance()->installTranslator(translator);
    }

    void loadOnMainThread()
    {
        // If this library is loaded after the QCoreApplication instance is
        // created (eg: because it is brought in by a plugin), there is no
        // guarantee this function will be called on the main thread.
        // QCoreApplication::installTranslator needs to be called on the main
        // thread, because it uses QCoreApplication::sendEvent.
        if (QThread::currentThread() == QCoreApplication::instance()->thread()) {
            load();
        } else {
            QTimer::singleShot(0, QCoreApplication::instance(), []() { load(); });
        }
    }
}

Q_COREAPP_STARTUP_FUNCTION(loadOnMainThread)
